@@ -9,7 +9,7 @@ from autosklearn.classification import AutoSklearnClassifier as ASK1
 import autosklearn.metrics
 
 optidoc='''
---method str any  'extra_trees', 'passive_aggressive', 'random_forest', 'sgd', 'gradient_boosting', 'mlp'
+--methods str+ any  'extra_trees', 'passive_aggressive', 'random_forest', 'sgd', 'gradient_boosting', 'mlp'
 --out str jsongoeshere
 --n_jobs int 1
 --time int 3600
@@ -19,17 +19,26 @@ optidoc='''
 #--metric str f1 assert f1 auc   TODO
 '''
 
+'''
+this gives all the calssifiers:
+import autosklearn.pipeline.components.classification as cls
+cls._classifiers.keys()
+'adaboost', 'bernoulli_nb', 'decision_tree', 'extra_trees', 'gaussian_nb', 'gradient_boosting', 'k_nearest_neighbors', 'lda', 'liblinear_svc', 'libsvm_svc', 'mlp', 'multinomial_nb', 'passive_aggressive', 'qda', 'random_forest', 'sgd'
+'''
+
 def optimize(X,Y,x,y, args):
 
-    if args.method == 'any':
-        estis =  ['extra_trees', 'passive_aggressive', 'random_forest', 'sgd', 'gradient_boosting', 'mlp']
+    if args.methods[0] == 'any':
+        estis =  None #['extra_trees', 'passive_aggressive', 'random_forest', 'sgd', 'gradient_boosting', 'mlp']
     else:
-        estis = [args.method]
+        estis = args.methods
 
 
     #include_estimators = estis,
     #include_preprocessors = ["no_preprocessing"] if not args.preprocess else None,
-    include = {}
+
+    include = {'classifier': estis} if estis else {}
+    print("ALLGOOD:", include)
     if not args.preprocess:
             include['feature_preprocessor'] =  ["no_preprocessing"]
             #include['data_preprocessor']     =  ['NoPreprocessing']
@@ -72,10 +81,13 @@ def main():
     if data[0].shape[1] < 100:
         print("SELECTED FEATURES: ", end='')
         pipeline = model.get_models_with_weights()[0][1]
-        if type(pipeline.steps[2][1].choice.preprocessor) == str:
-            print("all")
-        else:
-            print('\n',pipeline.steps[2][1].choice.preprocessor.get_support())
+        try:
+            if type(pipeline.steps[2][1].choice.preprocessor) == str:
+                print("all")
+            else:
+                print('\n',pipeline.steps[2][1].choice.preprocessor.get_support())
+        except:
+            pass
 
 
 if __name__ == "__main__":
